@@ -1,7 +1,7 @@
 """
 Type annotations for workmail service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmail/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmail/literals/)
 
 Usage::
 
@@ -39,8 +39,11 @@ __all__ = (
     "ResourceTypeType",
     "RetentionActionType",
     "UserRoleType",
+    "WorkMailServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -63,6 +66,7 @@ PermissionTypeType = Literal["FULL_ACCESS", "SEND_AS", "SEND_ON_BEHALF"]
 ResourceTypeType = Literal["EQUIPMENT", "ROOM"]
 RetentionActionType = Literal["DELETE", "NONE", "PERMANENTLY_DELETE"]
 UserRoleType = Literal["RESOURCE", "SYSTEM_USER", "USER"]
+WorkMailServiceName = Literal["workmail"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -94,6 +98,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -180,6 +185,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -216,6 +222,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -364,6 +371,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_aliases",
     "list_group_members",
@@ -374,3 +393,4 @@ PaginatorName = Literal[
     "list_resources",
     "list_users",
 ]
+RegionName = Literal["eu-west-1", "us-east-1", "us-west-2"]
