@@ -1,7 +1,7 @@
 """
 Type annotations for workmail service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmail/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmail/type_defs/)
 
 Usage::
 
@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     AccessControlRuleEffectType,
     DnsRecordVerificationStatusType,
@@ -101,30 +103,38 @@ __all__ = (
     "GroupTypeDef",
     "ListAccessControlRulesRequestRequestTypeDef",
     "ListAccessControlRulesResponseTypeDef",
+    "ListAliasesRequestListAliasesPaginateTypeDef",
     "ListAliasesRequestRequestTypeDef",
     "ListAliasesResponseTypeDef",
+    "ListGroupMembersRequestListGroupMembersPaginateTypeDef",
     "ListGroupMembersRequestRequestTypeDef",
     "ListGroupMembersResponseTypeDef",
+    "ListGroupsRequestListGroupsPaginateTypeDef",
     "ListGroupsRequestRequestTypeDef",
     "ListGroupsResponseTypeDef",
     "ListMailDomainsRequestRequestTypeDef",
     "ListMailDomainsResponseTypeDef",
     "ListMailboxExportJobsRequestRequestTypeDef",
     "ListMailboxExportJobsResponseTypeDef",
+    "ListMailboxPermissionsRequestListMailboxPermissionsPaginateTypeDef",
     "ListMailboxPermissionsRequestRequestTypeDef",
     "ListMailboxPermissionsResponseTypeDef",
     "ListMobileDeviceAccessOverridesRequestRequestTypeDef",
     "ListMobileDeviceAccessOverridesResponseTypeDef",
     "ListMobileDeviceAccessRulesRequestRequestTypeDef",
     "ListMobileDeviceAccessRulesResponseTypeDef",
+    "ListOrganizationsRequestListOrganizationsPaginateTypeDef",
     "ListOrganizationsRequestRequestTypeDef",
     "ListOrganizationsResponseTypeDef",
+    "ListResourceDelegatesRequestListResourceDelegatesPaginateTypeDef",
     "ListResourceDelegatesRequestRequestTypeDef",
     "ListResourceDelegatesResponseTypeDef",
+    "ListResourcesRequestListResourcesPaginateTypeDef",
     "ListResourcesRequestRequestTypeDef",
     "ListResourcesResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "ListUsersRequestListUsersPaginateTypeDef",
     "ListUsersRequestRequestTypeDef",
     "ListUsersResponseTypeDef",
     "MailDomainSummaryTypeDef",
@@ -163,19 +173,18 @@ __all__ = (
 AccessControlRuleTypeDef = TypedDict(
     "AccessControlRuleTypeDef",
     {
-        "Name": str,
-        "Effect": AccessControlRuleEffectType,
-        "Description": str,
-        "IpRanges": List[str],
-        "NotIpRanges": List[str],
-        "Actions": List[str],
-        "NotActions": List[str],
-        "UserIds": List[str],
-        "NotUserIds": List[str],
-        "DateCreated": datetime,
-        "DateModified": datetime,
+        "Name": NotRequired[str],
+        "Effect": NotRequired[AccessControlRuleEffectType],
+        "Description": NotRequired[str],
+        "IpRanges": NotRequired[List[str]],
+        "NotIpRanges": NotRequired[List[str]],
+        "Actions": NotRequired[List[str]],
+        "NotActions": NotRequired[List[str]],
+        "UserIds": NotRequired[List[str]],
+        "NotUserIds": NotRequired[List[str]],
+        "DateCreated": NotRequired[datetime],
+        "DateModified": NotRequired[datetime],
     },
-    total=False,
 )
 
 AssociateDelegateToResourceRequestRequestTypeDef = TypedDict(
@@ -199,11 +208,10 @@ AssociateMemberToGroupRequestRequestTypeDef = TypedDict(
 BookingOptionsTypeDef = TypedDict(
     "BookingOptionsTypeDef",
     {
-        "AutoAcceptRequests": bool,
-        "AutoDeclineRecurringRequests": bool,
-        "AutoDeclineConflictingRequests": bool,
+        "AutoAcceptRequests": NotRequired[bool],
+        "AutoDeclineRecurringRequests": NotRequired[bool],
+        "AutoDeclineConflictingRequests": NotRequired[bool],
     },
-    total=False,
 )
 
 CancelMailboxExportJobRequestRequestTypeDef = TypedDict(
@@ -240,38 +248,24 @@ CreateGroupResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateMobileDeviceAccessRuleRequestRequestTypeDef",
+CreateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
+    "CreateMobileDeviceAccessRuleRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "Name": str,
         "Effect": MobileDeviceAccessRuleEffectType,
+        "ClientToken": NotRequired[str],
+        "Description": NotRequired[str],
+        "DeviceTypes": NotRequired[Sequence[str]],
+        "NotDeviceTypes": NotRequired[Sequence[str]],
+        "DeviceModels": NotRequired[Sequence[str]],
+        "NotDeviceModels": NotRequired[Sequence[str]],
+        "DeviceOperatingSystems": NotRequired[Sequence[str]],
+        "NotDeviceOperatingSystems": NotRequired[Sequence[str]],
+        "DeviceUserAgents": NotRequired[Sequence[str]],
+        "NotDeviceUserAgents": NotRequired[Sequence[str]],
     },
 )
-_OptionalCreateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateMobileDeviceAccessRuleRequestRequestTypeDef",
-    {
-        "ClientToken": str,
-        "Description": str,
-        "DeviceTypes": Sequence[str],
-        "NotDeviceTypes": Sequence[str],
-        "DeviceModels": Sequence[str],
-        "NotDeviceModels": Sequence[str],
-        "DeviceOperatingSystems": Sequence[str],
-        "NotDeviceOperatingSystems": Sequence[str],
-        "DeviceUserAgents": Sequence[str],
-        "NotDeviceUserAgents": Sequence[str],
-    },
-    total=False,
-)
-
-
-class CreateMobileDeviceAccessRuleRequestRequestTypeDef(
-    _RequiredCreateMobileDeviceAccessRuleRequestRequestTypeDef,
-    _OptionalCreateMobileDeviceAccessRuleRequestRequestTypeDef,
-):
-    pass
-
 
 CreateMobileDeviceAccessRuleResponseTypeDef = TypedDict(
     "CreateMobileDeviceAccessRuleResponseTypeDef",
@@ -281,31 +275,17 @@ CreateMobileDeviceAccessRuleResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateOrganizationRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateOrganizationRequestRequestTypeDef",
+CreateOrganizationRequestRequestTypeDef = TypedDict(
+    "CreateOrganizationRequestRequestTypeDef",
     {
         "Alias": str,
+        "DirectoryId": NotRequired[str],
+        "ClientToken": NotRequired[str],
+        "Domains": NotRequired[Sequence["DomainTypeDef"]],
+        "KmsKeyArn": NotRequired[str],
+        "EnableInteroperability": NotRequired[bool],
     },
 )
-_OptionalCreateOrganizationRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateOrganizationRequestRequestTypeDef",
-    {
-        "DirectoryId": str,
-        "ClientToken": str,
-        "Domains": Sequence["DomainTypeDef"],
-        "KmsKeyArn": str,
-        "EnableInteroperability": bool,
-    },
-    total=False,
-)
-
-
-class CreateOrganizationRequestRequestTypeDef(
-    _RequiredCreateOrganizationRequestRequestTypeDef,
-    _OptionalCreateOrganizationRequestRequestTypeDef,
-):
-    pass
-
 
 CreateOrganizationResponseTypeDef = TypedDict(
     "CreateOrganizationResponseTypeDef",
@@ -416,28 +396,14 @@ DeleteMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredDeleteOrganizationRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteOrganizationRequestRequestTypeDef",
+DeleteOrganizationRequestRequestTypeDef = TypedDict(
+    "DeleteOrganizationRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "DeleteDirectory": bool,
+        "ClientToken": NotRequired[str],
     },
 )
-_OptionalDeleteOrganizationRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteOrganizationRequestRequestTypeDef",
-    {
-        "ClientToken": str,
-    },
-    total=False,
-)
-
-
-class DeleteOrganizationRequestRequestTypeDef(
-    _RequiredDeleteOrganizationRequestRequestTypeDef,
-    _OptionalDeleteOrganizationRequestRequestTypeDef,
-):
-    pass
-
 
 DeleteOrganizationResponseTypeDef = TypedDict(
     "DeleteOrganizationResponseTypeDef",
@@ -657,43 +623,28 @@ DisassociateMemberFromGroupRequestRequestTypeDef = TypedDict(
 DnsRecordTypeDef = TypedDict(
     "DnsRecordTypeDef",
     {
-        "Type": str,
-        "Hostname": str,
-        "Value": str,
+        "Type": NotRequired[str],
+        "Hostname": NotRequired[str],
+        "Value": NotRequired[str],
     },
-    total=False,
 )
 
 DomainTypeDef = TypedDict(
     "DomainTypeDef",
     {
-        "DomainName": str,
-        "HostedZoneId": str,
+        "DomainName": NotRequired[str],
+        "HostedZoneId": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredFolderConfigurationTypeDef = TypedDict(
-    "_RequiredFolderConfigurationTypeDef",
+FolderConfigurationTypeDef = TypedDict(
+    "FolderConfigurationTypeDef",
     {
         "Name": FolderNameType,
         "Action": RetentionActionType,
+        "Period": NotRequired[int],
     },
 )
-_OptionalFolderConfigurationTypeDef = TypedDict(
-    "_OptionalFolderConfigurationTypeDef",
-    {
-        "Period": int,
-    },
-    total=False,
-)
-
-
-class FolderConfigurationTypeDef(
-    _RequiredFolderConfigurationTypeDef, _OptionalFolderConfigurationTypeDef
-):
-    pass
-
 
 GetAccessControlEffectRequestRequestTypeDef = TypedDict(
     "GetAccessControlEffectRequestRequestTypeDef",
@@ -769,30 +720,16 @@ GetMailboxDetailsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetMobileDeviceAccessEffectRequestRequestTypeDef = TypedDict(
-    "_RequiredGetMobileDeviceAccessEffectRequestRequestTypeDef",
+GetMobileDeviceAccessEffectRequestRequestTypeDef = TypedDict(
+    "GetMobileDeviceAccessEffectRequestRequestTypeDef",
     {
         "OrganizationId": str,
+        "DeviceType": NotRequired[str],
+        "DeviceModel": NotRequired[str],
+        "DeviceOperatingSystem": NotRequired[str],
+        "DeviceUserAgent": NotRequired[str],
     },
 )
-_OptionalGetMobileDeviceAccessEffectRequestRequestTypeDef = TypedDict(
-    "_OptionalGetMobileDeviceAccessEffectRequestRequestTypeDef",
-    {
-        "DeviceType": str,
-        "DeviceModel": str,
-        "DeviceOperatingSystem": str,
-        "DeviceUserAgent": str,
-    },
-    total=False,
-)
-
-
-class GetMobileDeviceAccessEffectRequestRequestTypeDef(
-    _RequiredGetMobileDeviceAccessEffectRequestRequestTypeDef,
-    _OptionalGetMobileDeviceAccessEffectRequestRequestTypeDef,
-):
-    pass
-
 
 GetMobileDeviceAccessEffectResponseTypeDef = TypedDict(
     "GetMobileDeviceAccessEffectResponseTypeDef",
@@ -828,14 +765,13 @@ GetMobileDeviceAccessOverrideResponseTypeDef = TypedDict(
 GroupTypeDef = TypedDict(
     "GroupTypeDef",
     {
-        "Id": str,
-        "Email": str,
-        "Name": str,
-        "State": EntityStateType,
-        "EnabledDate": datetime,
-        "DisabledDate": datetime,
+        "Id": NotRequired[str],
+        "Email": NotRequired[str],
+        "Name": NotRequired[str],
+        "State": NotRequired[EntityStateType],
+        "EnabledDate": NotRequired[datetime],
+        "DisabledDate": NotRequired[datetime],
     },
-    total=False,
 )
 
 ListAccessControlRulesRequestRequestTypeDef = TypedDict(
@@ -853,29 +789,25 @@ ListAccessControlRulesResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListAliasesRequestRequestTypeDef = TypedDict(
-    "_RequiredListAliasesRequestRequestTypeDef",
+ListAliasesRequestListAliasesPaginateTypeDef = TypedDict(
+    "ListAliasesRequestListAliasesPaginateTypeDef",
     {
         "OrganizationId": str,
         "EntityId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
-_OptionalListAliasesRequestRequestTypeDef = TypedDict(
-    "_OptionalListAliasesRequestRequestTypeDef",
+
+ListAliasesRequestRequestTypeDef = TypedDict(
+    "ListAliasesRequestRequestTypeDef",
     {
-        "NextToken": str,
-        "MaxResults": int,
+        "OrganizationId": str,
+        "EntityId": str,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
-
-class ListAliasesRequestRequestTypeDef(
-    _RequiredListAliasesRequestRequestTypeDef, _OptionalListAliasesRequestRequestTypeDef
-):
-    pass
-
-
 ListAliasesResponseTypeDef = TypedDict(
     "ListAliasesResponseTypeDef",
     {
@@ -885,29 +817,25 @@ ListAliasesResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListGroupMembersRequestRequestTypeDef = TypedDict(
-    "_RequiredListGroupMembersRequestRequestTypeDef",
+ListGroupMembersRequestListGroupMembersPaginateTypeDef = TypedDict(
+    "ListGroupMembersRequestListGroupMembersPaginateTypeDef",
     {
         "OrganizationId": str,
         "GroupId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
-_OptionalListGroupMembersRequestRequestTypeDef = TypedDict(
-    "_OptionalListGroupMembersRequestRequestTypeDef",
+
+ListGroupMembersRequestRequestTypeDef = TypedDict(
+    "ListGroupMembersRequestRequestTypeDef",
     {
-        "NextToken": str,
-        "MaxResults": int,
+        "OrganizationId": str,
+        "GroupId": str,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
-
-class ListGroupMembersRequestRequestTypeDef(
-    _RequiredListGroupMembersRequestRequestTypeDef, _OptionalListGroupMembersRequestRequestTypeDef
-):
-    pass
-
-
 ListGroupMembersResponseTypeDef = TypedDict(
     "ListGroupMembersResponseTypeDef",
     {
@@ -917,28 +845,23 @@ ListGroupMembersResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListGroupsRequestRequestTypeDef = TypedDict(
-    "_RequiredListGroupsRequestRequestTypeDef",
+ListGroupsRequestListGroupsPaginateTypeDef = TypedDict(
+    "ListGroupsRequestListGroupsPaginateTypeDef",
     {
         "OrganizationId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
-_OptionalListGroupsRequestRequestTypeDef = TypedDict(
-    "_OptionalListGroupsRequestRequestTypeDef",
+
+ListGroupsRequestRequestTypeDef = TypedDict(
+    "ListGroupsRequestRequestTypeDef",
     {
-        "NextToken": str,
-        "MaxResults": int,
+        "OrganizationId": str,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
-
-class ListGroupsRequestRequestTypeDef(
-    _RequiredListGroupsRequestRequestTypeDef, _OptionalListGroupsRequestRequestTypeDef
-):
-    pass
-
-
 ListGroupsResponseTypeDef = TypedDict(
     "ListGroupsResponseTypeDef",
     {
@@ -948,27 +871,14 @@ ListGroupsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListMailDomainsRequestRequestTypeDef = TypedDict(
-    "_RequiredListMailDomainsRequestRequestTypeDef",
+ListMailDomainsRequestRequestTypeDef = TypedDict(
+    "ListMailDomainsRequestRequestTypeDef",
     {
         "OrganizationId": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListMailDomainsRequestRequestTypeDef = TypedDict(
-    "_OptionalListMailDomainsRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListMailDomainsRequestRequestTypeDef(
-    _RequiredListMailDomainsRequestRequestTypeDef, _OptionalListMailDomainsRequestRequestTypeDef
-):
-    pass
-
 
 ListMailDomainsResponseTypeDef = TypedDict(
     "ListMailDomainsResponseTypeDef",
@@ -979,28 +889,14 @@ ListMailDomainsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListMailboxExportJobsRequestRequestTypeDef = TypedDict(
-    "_RequiredListMailboxExportJobsRequestRequestTypeDef",
+ListMailboxExportJobsRequestRequestTypeDef = TypedDict(
+    "ListMailboxExportJobsRequestRequestTypeDef",
     {
         "OrganizationId": str,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
 )
-_OptionalListMailboxExportJobsRequestRequestTypeDef = TypedDict(
-    "_OptionalListMailboxExportJobsRequestRequestTypeDef",
-    {
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-
-class ListMailboxExportJobsRequestRequestTypeDef(
-    _RequiredListMailboxExportJobsRequestRequestTypeDef,
-    _OptionalListMailboxExportJobsRequestRequestTypeDef,
-):
-    pass
-
 
 ListMailboxExportJobsResponseTypeDef = TypedDict(
     "ListMailboxExportJobsResponseTypeDef",
@@ -1011,30 +907,25 @@ ListMailboxExportJobsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListMailboxPermissionsRequestRequestTypeDef = TypedDict(
-    "_RequiredListMailboxPermissionsRequestRequestTypeDef",
+ListMailboxPermissionsRequestListMailboxPermissionsPaginateTypeDef = TypedDict(
+    "ListMailboxPermissionsRequestListMailboxPermissionsPaginateTypeDef",
     {
         "OrganizationId": str,
         "EntityId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
-_OptionalListMailboxPermissionsRequestRequestTypeDef = TypedDict(
-    "_OptionalListMailboxPermissionsRequestRequestTypeDef",
+
+ListMailboxPermissionsRequestRequestTypeDef = TypedDict(
+    "ListMailboxPermissionsRequestRequestTypeDef",
     {
-        "NextToken": str,
-        "MaxResults": int,
+        "OrganizationId": str,
+        "EntityId": str,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
-
-class ListMailboxPermissionsRequestRequestTypeDef(
-    _RequiredListMailboxPermissionsRequestRequestTypeDef,
-    _OptionalListMailboxPermissionsRequestRequestTypeDef,
-):
-    pass
-
-
 ListMailboxPermissionsResponseTypeDef = TypedDict(
     "ListMailboxPermissionsResponseTypeDef",
     {
@@ -1044,30 +935,16 @@ ListMailboxPermissionsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListMobileDeviceAccessOverridesRequestRequestTypeDef = TypedDict(
-    "_RequiredListMobileDeviceAccessOverridesRequestRequestTypeDef",
+ListMobileDeviceAccessOverridesRequestRequestTypeDef = TypedDict(
+    "ListMobileDeviceAccessOverridesRequestRequestTypeDef",
     {
         "OrganizationId": str,
+        "UserId": NotRequired[str],
+        "DeviceId": NotRequired[str],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
 )
-_OptionalListMobileDeviceAccessOverridesRequestRequestTypeDef = TypedDict(
-    "_OptionalListMobileDeviceAccessOverridesRequestRequestTypeDef",
-    {
-        "UserId": str,
-        "DeviceId": str,
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-
-class ListMobileDeviceAccessOverridesRequestRequestTypeDef(
-    _RequiredListMobileDeviceAccessOverridesRequestRequestTypeDef,
-    _OptionalListMobileDeviceAccessOverridesRequestRequestTypeDef,
-):
-    pass
-
 
 ListMobileDeviceAccessOverridesResponseTypeDef = TypedDict(
     "ListMobileDeviceAccessOverridesResponseTypeDef",
@@ -1093,13 +970,19 @@ ListMobileDeviceAccessRulesResponseTypeDef = TypedDict(
     },
 )
 
+ListOrganizationsRequestListOrganizationsPaginateTypeDef = TypedDict(
+    "ListOrganizationsRequestListOrganizationsPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListOrganizationsRequestRequestTypeDef = TypedDict(
     "ListOrganizationsRequestRequestTypeDef",
     {
-        "NextToken": str,
-        "MaxResults": int,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListOrganizationsResponseTypeDef = TypedDict(
@@ -1111,30 +994,25 @@ ListOrganizationsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListResourceDelegatesRequestRequestTypeDef = TypedDict(
-    "_RequiredListResourceDelegatesRequestRequestTypeDef",
+ListResourceDelegatesRequestListResourceDelegatesPaginateTypeDef = TypedDict(
+    "ListResourceDelegatesRequestListResourceDelegatesPaginateTypeDef",
     {
         "OrganizationId": str,
         "ResourceId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
-_OptionalListResourceDelegatesRequestRequestTypeDef = TypedDict(
-    "_OptionalListResourceDelegatesRequestRequestTypeDef",
+
+ListResourceDelegatesRequestRequestTypeDef = TypedDict(
+    "ListResourceDelegatesRequestRequestTypeDef",
     {
-        "NextToken": str,
-        "MaxResults": int,
+        "OrganizationId": str,
+        "ResourceId": str,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
-
-class ListResourceDelegatesRequestRequestTypeDef(
-    _RequiredListResourceDelegatesRequestRequestTypeDef,
-    _OptionalListResourceDelegatesRequestRequestTypeDef,
-):
-    pass
-
-
 ListResourceDelegatesResponseTypeDef = TypedDict(
     "ListResourceDelegatesResponseTypeDef",
     {
@@ -1144,28 +1022,23 @@ ListResourceDelegatesResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListResourcesRequestRequestTypeDef = TypedDict(
-    "_RequiredListResourcesRequestRequestTypeDef",
+ListResourcesRequestListResourcesPaginateTypeDef = TypedDict(
+    "ListResourcesRequestListResourcesPaginateTypeDef",
     {
         "OrganizationId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
-_OptionalListResourcesRequestRequestTypeDef = TypedDict(
-    "_OptionalListResourcesRequestRequestTypeDef",
+
+ListResourcesRequestRequestTypeDef = TypedDict(
+    "ListResourcesRequestRequestTypeDef",
     {
-        "NextToken": str,
-        "MaxResults": int,
+        "OrganizationId": str,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
-
-class ListResourcesRequestRequestTypeDef(
-    _RequiredListResourcesRequestRequestTypeDef, _OptionalListResourcesRequestRequestTypeDef
-):
-    pass
-
-
 ListResourcesResponseTypeDef = TypedDict(
     "ListResourcesResponseTypeDef",
     {
@@ -1190,28 +1063,23 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListUsersRequestRequestTypeDef = TypedDict(
-    "_RequiredListUsersRequestRequestTypeDef",
+ListUsersRequestListUsersPaginateTypeDef = TypedDict(
+    "ListUsersRequestListUsersPaginateTypeDef",
     {
         "OrganizationId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
-_OptionalListUsersRequestRequestTypeDef = TypedDict(
-    "_OptionalListUsersRequestRequestTypeDef",
+
+ListUsersRequestRequestTypeDef = TypedDict(
+    "ListUsersRequestRequestTypeDef",
     {
-        "NextToken": str,
-        "MaxResults": int,
+        "OrganizationId": str,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
-
-class ListUsersRequestRequestTypeDef(
-    _RequiredListUsersRequestRequestTypeDef, _OptionalListUsersRequestRequestTypeDef
-):
-    pass
-
-
 ListUsersResponseTypeDef = TypedDict(
     "ListUsersResponseTypeDef",
     {
@@ -1224,104 +1092,96 @@ ListUsersResponseTypeDef = TypedDict(
 MailDomainSummaryTypeDef = TypedDict(
     "MailDomainSummaryTypeDef",
     {
-        "DomainName": str,
-        "DefaultDomain": bool,
+        "DomainName": NotRequired[str],
+        "DefaultDomain": NotRequired[bool],
     },
-    total=False,
 )
 
 MailboxExportJobTypeDef = TypedDict(
     "MailboxExportJobTypeDef",
     {
-        "JobId": str,
-        "EntityId": str,
-        "Description": str,
-        "S3BucketName": str,
-        "S3Path": str,
-        "EstimatedProgress": int,
-        "State": MailboxExportJobStateType,
-        "StartTime": datetime,
-        "EndTime": datetime,
+        "JobId": NotRequired[str],
+        "EntityId": NotRequired[str],
+        "Description": NotRequired[str],
+        "S3BucketName": NotRequired[str],
+        "S3Path": NotRequired[str],
+        "EstimatedProgress": NotRequired[int],
+        "State": NotRequired[MailboxExportJobStateType],
+        "StartTime": NotRequired[datetime],
+        "EndTime": NotRequired[datetime],
     },
-    total=False,
 )
 
 MemberTypeDef = TypedDict(
     "MemberTypeDef",
     {
-        "Id": str,
-        "Name": str,
-        "Type": MemberTypeType,
-        "State": EntityStateType,
-        "EnabledDate": datetime,
-        "DisabledDate": datetime,
+        "Id": NotRequired[str],
+        "Name": NotRequired[str],
+        "Type": NotRequired[MemberTypeType],
+        "State": NotRequired[EntityStateType],
+        "EnabledDate": NotRequired[datetime],
+        "DisabledDate": NotRequired[datetime],
     },
-    total=False,
 )
 
 MobileDeviceAccessMatchedRuleTypeDef = TypedDict(
     "MobileDeviceAccessMatchedRuleTypeDef",
     {
-        "MobileDeviceAccessRuleId": str,
-        "Name": str,
+        "MobileDeviceAccessRuleId": NotRequired[str],
+        "Name": NotRequired[str],
     },
-    total=False,
 )
 
 MobileDeviceAccessOverrideTypeDef = TypedDict(
     "MobileDeviceAccessOverrideTypeDef",
     {
-        "UserId": str,
-        "DeviceId": str,
-        "Effect": MobileDeviceAccessRuleEffectType,
-        "Description": str,
-        "DateCreated": datetime,
-        "DateModified": datetime,
+        "UserId": NotRequired[str],
+        "DeviceId": NotRequired[str],
+        "Effect": NotRequired[MobileDeviceAccessRuleEffectType],
+        "Description": NotRequired[str],
+        "DateCreated": NotRequired[datetime],
+        "DateModified": NotRequired[datetime],
     },
-    total=False,
 )
 
 MobileDeviceAccessRuleTypeDef = TypedDict(
     "MobileDeviceAccessRuleTypeDef",
     {
-        "MobileDeviceAccessRuleId": str,
-        "Name": str,
-        "Description": str,
-        "Effect": MobileDeviceAccessRuleEffectType,
-        "DeviceTypes": List[str],
-        "NotDeviceTypes": List[str],
-        "DeviceModels": List[str],
-        "NotDeviceModels": List[str],
-        "DeviceOperatingSystems": List[str],
-        "NotDeviceOperatingSystems": List[str],
-        "DeviceUserAgents": List[str],
-        "NotDeviceUserAgents": List[str],
-        "DateCreated": datetime,
-        "DateModified": datetime,
+        "MobileDeviceAccessRuleId": NotRequired[str],
+        "Name": NotRequired[str],
+        "Description": NotRequired[str],
+        "Effect": NotRequired[MobileDeviceAccessRuleEffectType],
+        "DeviceTypes": NotRequired[List[str]],
+        "NotDeviceTypes": NotRequired[List[str]],
+        "DeviceModels": NotRequired[List[str]],
+        "NotDeviceModels": NotRequired[List[str]],
+        "DeviceOperatingSystems": NotRequired[List[str]],
+        "NotDeviceOperatingSystems": NotRequired[List[str]],
+        "DeviceUserAgents": NotRequired[List[str]],
+        "NotDeviceUserAgents": NotRequired[List[str]],
+        "DateCreated": NotRequired[datetime],
+        "DateModified": NotRequired[datetime],
     },
-    total=False,
 )
 
 OrganizationSummaryTypeDef = TypedDict(
     "OrganizationSummaryTypeDef",
     {
-        "OrganizationId": str,
-        "Alias": str,
-        "DefaultMailDomain": str,
-        "ErrorMessage": str,
-        "State": str,
+        "OrganizationId": NotRequired[str],
+        "Alias": NotRequired[str],
+        "DefaultMailDomain": NotRequired[str],
+        "ErrorMessage": NotRequired[str],
+        "State": NotRequired[str],
     },
-    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 PermissionTypeDef = TypedDict(
@@ -1333,35 +1193,21 @@ PermissionTypeDef = TypedDict(
     },
 )
 
-_RequiredPutAccessControlRuleRequestRequestTypeDef = TypedDict(
-    "_RequiredPutAccessControlRuleRequestRequestTypeDef",
+PutAccessControlRuleRequestRequestTypeDef = TypedDict(
+    "PutAccessControlRuleRequestRequestTypeDef",
     {
         "Name": str,
         "Effect": AccessControlRuleEffectType,
         "Description": str,
         "OrganizationId": str,
+        "IpRanges": NotRequired[Sequence[str]],
+        "NotIpRanges": NotRequired[Sequence[str]],
+        "Actions": NotRequired[Sequence[str]],
+        "NotActions": NotRequired[Sequence[str]],
+        "UserIds": NotRequired[Sequence[str]],
+        "NotUserIds": NotRequired[Sequence[str]],
     },
 )
-_OptionalPutAccessControlRuleRequestRequestTypeDef = TypedDict(
-    "_OptionalPutAccessControlRuleRequestRequestTypeDef",
-    {
-        "IpRanges": Sequence[str],
-        "NotIpRanges": Sequence[str],
-        "Actions": Sequence[str],
-        "NotActions": Sequence[str],
-        "UserIds": Sequence[str],
-        "NotUserIds": Sequence[str],
-    },
-    total=False,
-)
-
-
-class PutAccessControlRuleRequestRequestTypeDef(
-    _RequiredPutAccessControlRuleRequestRequestTypeDef,
-    _OptionalPutAccessControlRuleRequestRequestTypeDef,
-):
-    pass
-
 
 PutEmailMonitoringConfigurationRequestRequestTypeDef = TypedDict(
     "PutEmailMonitoringConfigurationRequestRequestTypeDef",
@@ -1390,78 +1236,36 @@ PutMailboxPermissionsRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredPutMobileDeviceAccessOverrideRequestRequestTypeDef = TypedDict(
-    "_RequiredPutMobileDeviceAccessOverrideRequestRequestTypeDef",
+PutMobileDeviceAccessOverrideRequestRequestTypeDef = TypedDict(
+    "PutMobileDeviceAccessOverrideRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "UserId": str,
         "DeviceId": str,
         "Effect": MobileDeviceAccessRuleEffectType,
+        "Description": NotRequired[str],
     },
 )
-_OptionalPutMobileDeviceAccessOverrideRequestRequestTypeDef = TypedDict(
-    "_OptionalPutMobileDeviceAccessOverrideRequestRequestTypeDef",
-    {
-        "Description": str,
-    },
-    total=False,
-)
 
-
-class PutMobileDeviceAccessOverrideRequestRequestTypeDef(
-    _RequiredPutMobileDeviceAccessOverrideRequestRequestTypeDef,
-    _OptionalPutMobileDeviceAccessOverrideRequestRequestTypeDef,
-):
-    pass
-
-
-_RequiredPutRetentionPolicyRequestRequestTypeDef = TypedDict(
-    "_RequiredPutRetentionPolicyRequestRequestTypeDef",
+PutRetentionPolicyRequestRequestTypeDef = TypedDict(
+    "PutRetentionPolicyRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "Name": str,
         "FolderConfigurations": Sequence["FolderConfigurationTypeDef"],
+        "Id": NotRequired[str],
+        "Description": NotRequired[str],
     },
 )
-_OptionalPutRetentionPolicyRequestRequestTypeDef = TypedDict(
-    "_OptionalPutRetentionPolicyRequestRequestTypeDef",
-    {
-        "Id": str,
-        "Description": str,
-    },
-    total=False,
-)
 
-
-class PutRetentionPolicyRequestRequestTypeDef(
-    _RequiredPutRetentionPolicyRequestRequestTypeDef,
-    _OptionalPutRetentionPolicyRequestRequestTypeDef,
-):
-    pass
-
-
-_RequiredRegisterMailDomainRequestRequestTypeDef = TypedDict(
-    "_RequiredRegisterMailDomainRequestRequestTypeDef",
+RegisterMailDomainRequestRequestTypeDef = TypedDict(
+    "RegisterMailDomainRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "DomainName": str,
+        "ClientToken": NotRequired[str],
     },
 )
-_OptionalRegisterMailDomainRequestRequestTypeDef = TypedDict(
-    "_OptionalRegisterMailDomainRequestRequestTypeDef",
-    {
-        "ClientToken": str,
-    },
-    total=False,
-)
-
-
-class RegisterMailDomainRequestRequestTypeDef(
-    _RequiredRegisterMailDomainRequestRequestTypeDef,
-    _OptionalRegisterMailDomainRequestRequestTypeDef,
-):
-    pass
-
 
 RegisterToWorkMailRequestRequestTypeDef = TypedDict(
     "RegisterToWorkMailRequestRequestTypeDef",
@@ -1484,15 +1288,14 @@ ResetPasswordRequestRequestTypeDef = TypedDict(
 ResourceTypeDef = TypedDict(
     "ResourceTypeDef",
     {
-        "Id": str,
-        "Email": str,
-        "Name": str,
-        "Type": ResourceTypeType,
-        "State": EntityStateType,
-        "EnabledDate": datetime,
-        "DisabledDate": datetime,
+        "Id": NotRequired[str],
+        "Email": NotRequired[str],
+        "Name": NotRequired[str],
+        "Type": NotRequired[ResourceTypeType],
+        "State": NotRequired[EntityStateType],
+        "EnabledDate": NotRequired[datetime],
+        "DisabledDate": NotRequired[datetime],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -1506,8 +1309,8 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredStartMailboxExportJobRequestRequestTypeDef = TypedDict(
-    "_RequiredStartMailboxExportJobRequestRequestTypeDef",
+StartMailboxExportJobRequestRequestTypeDef = TypedDict(
+    "StartMailboxExportJobRequestRequestTypeDef",
     {
         "ClientToken": str,
         "OrganizationId": str,
@@ -1516,23 +1319,9 @@ _RequiredStartMailboxExportJobRequestRequestTypeDef = TypedDict(
         "KmsKeyArn": str,
         "S3BucketName": str,
         "S3Prefix": str,
+        "Description": NotRequired[str],
     },
 )
-_OptionalStartMailboxExportJobRequestRequestTypeDef = TypedDict(
-    "_OptionalStartMailboxExportJobRequestRequestTypeDef",
-    {
-        "Description": str,
-    },
-    total=False,
-)
-
-
-class StartMailboxExportJobRequestRequestTypeDef(
-    _RequiredStartMailboxExportJobRequestRequestTypeDef,
-    _OptionalStartMailboxExportJobRequestRequestTypeDef,
-):
-    pass
-
 
 StartMailboxExportJobResponseTypeDef = TypedDict(
     "StartMailboxExportJobResponseTypeDef",
@@ -1583,38 +1372,24 @@ UpdateMailboxQuotaRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateMobileDeviceAccessRuleRequestRequestTypeDef",
+UpdateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
+    "UpdateMobileDeviceAccessRuleRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "MobileDeviceAccessRuleId": str,
         "Name": str,
         "Effect": MobileDeviceAccessRuleEffectType,
+        "Description": NotRequired[str],
+        "DeviceTypes": NotRequired[Sequence[str]],
+        "NotDeviceTypes": NotRequired[Sequence[str]],
+        "DeviceModels": NotRequired[Sequence[str]],
+        "NotDeviceModels": NotRequired[Sequence[str]],
+        "DeviceOperatingSystems": NotRequired[Sequence[str]],
+        "NotDeviceOperatingSystems": NotRequired[Sequence[str]],
+        "DeviceUserAgents": NotRequired[Sequence[str]],
+        "NotDeviceUserAgents": NotRequired[Sequence[str]],
     },
 )
-_OptionalUpdateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateMobileDeviceAccessRuleRequestRequestTypeDef",
-    {
-        "Description": str,
-        "DeviceTypes": Sequence[str],
-        "NotDeviceTypes": Sequence[str],
-        "DeviceModels": Sequence[str],
-        "NotDeviceModels": Sequence[str],
-        "DeviceOperatingSystems": Sequence[str],
-        "NotDeviceOperatingSystems": Sequence[str],
-        "DeviceUserAgents": Sequence[str],
-        "NotDeviceUserAgents": Sequence[str],
-    },
-    total=False,
-)
-
-
-class UpdateMobileDeviceAccessRuleRequestRequestTypeDef(
-    _RequiredUpdateMobileDeviceAccessRuleRequestRequestTypeDef,
-    _OptionalUpdateMobileDeviceAccessRuleRequestRequestTypeDef,
-):
-    pass
-
 
 UpdatePrimaryEmailAddressRequestRequestTypeDef = TypedDict(
     "UpdatePrimaryEmailAddressRequestRequestTypeDef",
@@ -1625,40 +1400,26 @@ UpdatePrimaryEmailAddressRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateResourceRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateResourceRequestRequestTypeDef",
+UpdateResourceRequestRequestTypeDef = TypedDict(
+    "UpdateResourceRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "ResourceId": str,
+        "Name": NotRequired[str],
+        "BookingOptions": NotRequired["BookingOptionsTypeDef"],
     },
 )
-_OptionalUpdateResourceRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateResourceRequestRequestTypeDef",
-    {
-        "Name": str,
-        "BookingOptions": "BookingOptionsTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateResourceRequestRequestTypeDef(
-    _RequiredUpdateResourceRequestRequestTypeDef, _OptionalUpdateResourceRequestRequestTypeDef
-):
-    pass
-
 
 UserTypeDef = TypedDict(
     "UserTypeDef",
     {
-        "Id": str,
-        "Email": str,
-        "Name": str,
-        "DisplayName": str,
-        "State": EntityStateType,
-        "UserRole": UserRoleType,
-        "EnabledDate": datetime,
-        "DisabledDate": datetime,
+        "Id": NotRequired[str],
+        "Email": NotRequired[str],
+        "Name": NotRequired[str],
+        "DisplayName": NotRequired[str],
+        "State": NotRequired[EntityStateType],
+        "UserRole": NotRequired[UserRoleType],
+        "EnabledDate": NotRequired[datetime],
+        "DisabledDate": NotRequired[datetime],
     },
-    total=False,
 )
